import {select, 
        csv, 
        scaleLinear, 
        extent, 
        axisLeft, 
        axisBottom,
        format} from 'd3';
const svg = d3.select("svg");

const width = +svg.attr("width");
const height = +svg.attr("height"); //unary +-operator converts string to number

const render = data => {
  const Title = 'Cars';
  const xValue = d => d.mpg;
  const xAxisLabel = 'MPG';
  
  const yValue = d => d.weight;
  const yAxisLabel = 'Weight';

  
  const margin = {left: 150, top:40, right: 40, bottom:60};
  
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scaleLinear()
  	.domain(extent(data, xValue))
  	.range([0, innerWidth])
  	.nice();
  
  const yScale = scaleLinear()
  	.domain(extent(data, yValue))
  	.range([0, innerHeight])
  	.nice()
;
  
  const yAxis = axisLeft(yScale); //returns a function 
  const xAxis = axisBottom(xScale); //returns a function 
  const xAxisTickFormat = n => format('.3s')(n).replace('G', 'B'); 
  
  const g = svg.append('g')
  .attr('transform', `translate(${margin.left}, ${margin.top})`);
    
  //yAxis(g.append('g')); Which is equal to:
  const yAxisGroup =
  g.append('g').call(yAxis.tickSize(-innerWidth));
  	//.selectAll('.domain, .tick line').remove();
  
  
  yAxisGroup.append('text')
    .attr('class', 'axis-label')
  	//.attr('fill', 'black')
    .attr('x', -innerHeight/2)
  	.attr('y', -90)
  	.text(yAxisLabel)
    .attr('transform', `rotate(-90)`);
  //translate(${-100, 0})`);
;

  
  
  
  const xAxisGroup =   g.append('g').call(
    xAxis.tickFormat(xAxisTickFormat)
    .tickSize(-innerHeight)
  	.tickPadding(10)
  	)
    .attr('transform', `translate(0, ${innerHeight})`);

  xAxisGroup.select('.domain').remove();
  
  xAxisGroup.append('text')
  	.attr('y', 50)
  	.attr('x', innerWidth/2)
  	//.attr('fill', 'black')
  	.text(xAxisLabel);

 
  g.append('text')
  	.attr('y', -10)
  	.text(Title);

  
  g.selectAll('circle').data(data)
  	.enter().append('circle')
  		.attr('cy', d => yScale(yValue(d)))
  		.attr('cx', d => xScale(xValue(d)))
  		.attr('r', d => 10);
};
csv('data.csv').then(data => {
  data.forEach(
    d => {
      d.mpg = +d.mpg;
      
         }  
  )
  render(data);

})
